pub struct Mort<'a> {
data: FontData<'a>,
}Expand description
The mort (Glyph Metamorphosis) table.
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Mort<'a>
impl<'a> Mort<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a, Args = ()>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a, Args = ()>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
just use the base type directly
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
pub fn chains(&self) -> VarLenArray<'a, Chain<'a>>
pub fn version_byte_range(&self) -> Range<usize> ⓘ
pub fn unused_byte_range(&self) -> Range<usize> ⓘ
pub fn n_chains_byte_range(&self) -> Range<usize> ⓘ
pub fn chains_byte_range(&self) -> Range<usize> ⓘ